@@ -1,7 +1,7 @@
 """Get Statue global configuration."""
 from copy import deepcopy
 from pathlib import Path
-from typing import Any, List, MutableMapping, Optional
+from typing import Any, List, MutableMapping, Optional, Union
 
 import toml
 
@@ -20,7 +20,7 @@ from statue.constants import (
     STANDARD,
     STATUE,
 )
-from statue.excptions import (
+from statue.exceptions import (
     EmptyConfiguration,
     InvalidCommand,
     InvalidStatueConfiguration,
@@ -36,6 +36,13 @@ class Configuration:
     __default_configuration: Optional[MutableMapping[str, Any]] = None
     __statue_configuration: Optional[MutableMapping[str, Any]] = None
 
+    @classmethod
+    def configuration_path(cls, directory: Union[Path, str]) -> Path:
+        """Get default path of configuration file in directory."""
+        if isinstance(directory, str):
+            directory = Path(directory)
+        return directory / "statue.toml"
+
     @classmethod
     def default_configuration(cls) -> Optional[MutableMapping[str, Any]]:
         """Getter of default configuration."""
@@ -101,20 +108,24 @@ class Configuration:
     @classmethod
     def sources_configuration(
         cls,
-    ) -> Optional[MutableMapping[str, MutableMapping[str, Any]]]:
+    ) -> MutableMapping[str, MutableMapping[str, Any]]:
         """Getter of the sources configuration."""
-        return cls.statue_configuration().get(SOURCES, None)
+        sources_configuration: Optional[
+            MutableMapping[str, MutableMapping[str, Any]]
+        ] = cls.statue_configuration().get(SOURCES, None)
+        if sources_configuration is None:
+            raise MissingConfiguration(SOURCES)
+        return sources_configuration
 
     @classmethod
     def sources_list(cls) -> List[str]:
         """Getter of the commands list."""
-        sources_configuration = cls.sources_configuration()
-        if sources_configuration is None:
-            return []
-        return list(sources_configuration.keys())
+        return list(cls.sources_configuration().keys())
 
     @classmethod
-    def get_source_configuration(cls, source: str) -> MutableMapping[str, Any]:
+    def get_source_configuration(
+        cls, source: Union[Path, str]
+    ) -> MutableMapping[str, Any]:
         """
         Get configuration dictionary of a context.
 
@@ -125,9 +136,9 @@ class Configuration:
         set.
         """
         source_configuration = cls.sources_configuration()
-        if source_configuration is None:
-            raise MissingConfiguration(SOURCES)
-        return source_configuration[source]
+        if isinstance(source, Path):
+            source = str(source)
+        return source_configuration.get(source, {})
 
     @classmethod
     def contexts_configuration(cls) -> Optional[MutableMapping[str, Any]]:
@@ -215,16 +226,24 @@ class Configuration:
                 allow_list=allow_list,
                 deny_list=deny_list,
             )
+        contexts = [] if contexts is None else contexts
+        for context in contexts:
+            context_obj = command_configuration.get(context, None)
+            if not isinstance(context_obj, dict):
+                continue
+            command_configuration = cls.__combine_command_setups(
+                command_configuration, context_obj
+            )
         return Command(
             name=command_name,
-            args=cls.__read_command_args(command_configuration, contexts=contexts),
+            args=command_configuration.get(ARGS, []),
             help=command_configuration[HELP],
         )
 
     @classmethod
     def load_configuration(
         cls,
-        statue_configuration_path: Path,
+        statue_configuration_path: Optional[Union[str, Path]] = None,
     ) -> None:
         """
         Load statue configuration.
@@ -235,6 +254,10 @@ class Configuration:
         :param statue_configuration_path: User-defined file path containing
         repository-specific configurations
         """
+        if statue_configuration_path is None:
+            statue_configuration_path = cls.configuration_path(Path.cwd())
+        if isinstance(statue_configuration_path, str):
+            statue_configuration_path = Path(statue_configuration_path)
         cls.set_statue_configuration(
             cls.__build_configuration(statue_configuration_path)
         )
@@ -301,7 +324,9 @@ class Configuration:
         commands_configuration = deepcopy(default_commands_configuration)
         for command_name, command_setups in statue_commands_configuration.items():
             if command_name in commands_configuration:
-                commands_configuration[command_name].update(command_setups)
+                commands_configuration[command_name] = cls.__combine_command_setups(
+                    commands_configuration[command_name], command_setups
+                )
             else:
                 commands_configuration[command_name] = command_setups
         return commands_configuration
@@ -380,23 +405,42 @@ class Configuration:
         return setups.get(STANDARD, True)
 
     @classmethod
-    def __read_command_args(
-        cls, setups: MutableMapping[str, Any], contexts: Optional[List[str]]
-    ) -> List[str]:
-        base_args = list(setups.get(ARGS, []))
-        if contexts is None:
-            return base_args
-        for command_context in contexts:
-            context_obj = setups.get(command_context, None)
-            if not isinstance(context_obj, dict):
-                continue
-            args: List[str] = context_obj.get(ARGS, None)
-            if args is not None:
-                return args
-            add_args = context_obj.get(ADD_ARGS, None)
-            if add_args is not None:
-                base_args.extend(add_args)
-            clear_args = context_obj.get(CLEAR_ARGS, False)
-            if clear_args:
-                return []
+    def __combine_command_setups(
+        cls,
+        base_setup: MutableMapping[str, Any],
+        setup: MutableMapping[str, Any],
+    ) -> MutableMapping[str, Any]:
+        new_setup = cls.__remove_args_keys(base_setup)
+        args = cls.__combine_command_args(base_setup.get(ARGS, None), setup)
+        if args is not None:
+            new_setup[ARGS] = args
+        new_setup.update(cls.__remove_args_keys(setup))
+        return new_setup
+
+    @classmethod
+    def __combine_command_args(
+        cls, base_args: Optional[List[str]], command_setup: MutableMapping[str, Any]
+    ) -> Optional[List[str]]:
+        base_args = [] if base_args is None else base_args
+        args: List[str] = command_setup.get(ARGS, None)
+        if args is not None:
+            return args
+        add_args = command_setup.get(ADD_ARGS, None)
+        if add_args is not None:
+            return base_args + add_args
+        clear_args = command_setup.get(CLEAR_ARGS, False)
+        if clear_args:
+            return None
+        if len(base_args) == 0:
+            return None
         return base_args
+
+    @classmethod
+    def __remove_args_keys(
+        cls, command_setup: MutableMapping[str, Any]
+    ) -> MutableMapping[str, Any]:
+        return {
+            key: value
+            for key, value in command_setup.items()
+            if key not in [ARGS, ADD_ARGS, CLEAR_ARGS]
+        }
